# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DeletionResponse(Model):
    """DeletionResponse.

    :param is_deleted:
    :type is_deleted: bool
    :param issues:
    :type issues:
     list[~dynamics.customerinsights.api.models.DependencyValidationIssue]
    """

    _attribute_map = {
        'is_deleted': {'key': 'isDeleted', 'type': 'bool'},
        'issues': {'key': 'issues', 'type': '[DependencyValidationIssue]'},
    }

    def __init__(self, *, is_deleted: bool=None, issues=None, **kwargs) -> None:
        super(DeletionResponse, self).__init__(**kwargs)
        self.is_deleted = is_deleted
        self.issues = issues
